@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.7"
+__version__ = "1.0.9"
 
 import argparse
 import base64
@@ -37,26 +37,6 @@ def find_git_url() -> str or None:
     return None
 
 
-def fetch_latest_commit_hash() -> str or None:
-    """
-    Scan the .git folder for the latest commit hash
-    :return:
-    """
-
-    url = "https://api.github.com/repos/MeshMonitors-Remote-1/ShopifyMonitor/commits"
-
-    payload = {}
-    headers = {
-        'Accept': 'application/vnd.github.v3+json',
-        'Authorization': 'Bearer -',
-        'Cookie': '_octo=GH1.1.613847517.1655532567; logged_in=no'
-    }
-
-    response = requests.request("GET", url, headers=headers, data=payload)
-
-    print(response.text)
-
-
 def download_and_replace_file(session, url, file_path: str, auth_token: str):
     """
     Download a file from a url and replace the file at the given path
@@ -87,75 +67,112 @@ def download_and_replace_file(session, url, file_path: str, auth_token: str):
         f.write(file_content)
 
 
-def get_update_file(auth_token: str, repo_url) -> str or None:
+def get_update_file(auth_token: str, repo_url, force: bool) -> str or None:
     """
     Scan the .git folder for the latest commit hash
+    :param force:
     :param auth_token:
     :param repo_url:
     :return:
     """
-
-    url = f"https://api.github.com/repos/{repo_url}/contents/UPDATE_FILE"
     session = requests.Session()
 
-    headers = {
-        'Accept': 'application/vnd.github.v3+json',
-        'Authorization': f'Bearer {auth_token}',
-        'Cookie': '_octo=GH1.1.613847517.1655532567; logged_in=no'
-    }
+    try:
+        url = f"https://api.github.com/repos/{repo_url}/contents/UPDATE_FILE"
+        headers = {
+            'Accept': 'application/vnd.github.v3+json',
+            'Authorization': f'Bearer {auth_token}',
+            'Cookie': '_octo=GH1.1.613847517.1655532567; logged_in=no'
+        }
 
-    response = session.request("GET", url, headers=headers)
+        response = session.request("GET", url, headers=headers)
 
-    if response.status_code == 200:
-        # Get the file content and since it's a base64 encoded string, decode it
-        content = base64.b64decode(response.json()['content'])
+        if response.status_code == 200:
+            # Get the file content and since it's a base64 encoded string, decode it
+            content = base64.b64decode(response.json()['content'])
 
-        # Convert the content to a string
-        content = content.decode('utf-8')
-
-        ask_for_confirmation = input("Do you want to replace the update/download files with the latest version? [y/n] ")
-        if ask_for_confirmation.lower() == 'y':
-            if len(content) > 0:
-                change_list = content.split('\n')
-                for change in change_list:
-                    change_wanted = change.split(':')
-                    if len(change_wanted) > 1:
-                        change_action = change_wanted[0]
-                        change_file = change_wanted[1]
-                        if change_action == 'overwrite':
-                            print("Overwrite/Download file: %s" % change_file)
-                            link = f"https://api.github.com/repos/" \
-                                   f"{repo_url}/contents/{change_file}"
-                            download_and_replace_file(session, link, change_file, auth_token)
+            # Convert the content to a string
+            content = content.decode('utf-8')
+            if force:
+                if len(content) > 0:
+                    change_list = content.split('\n')
+                    for change in change_list:
+                        change_wanted = change.split(':')
+                        if len(change_wanted) > 1:
+                            change_action = change_wanted[0]
+                            change_file = change_wanted[1]
+                            if change_action == 'overwrite':
+                                print("Overwrite/Download file: %s" % change_file)
+                                link = f"https://api.github.com/repos/" \
+                                       f"{repo_url}/contents/{change_file}"
+                                download_and_replace_file(session, link, change_file, auth_token)
+            else:
+                ask_for_confirmation = input("Do you want to replace the update/download files with the latest version? ["
+                                             "y/n] ")
+                if ask_for_confirmation.lower() == 'y':
+                    if len(content) > 0:
+                        change_list = content.split('\n')
+                        for change in change_list:
+                            change_wanted = change.split(':')
+                            if len(change_wanted) > 1:
+                                change_action = change_wanted[0]
+                                change_file = change_wanted[1]
+                                if change_action == 'overwrite':
+                                    print("Overwrite/Download file: %s" % change_file)
+                                    link = f"https://api.github.com/repos/" \
+                                           f"{repo_url}/contents/{change_file}"
+                                    download_and_replace_file(session, link, change_file, auth_token)
+                else:
+                    print("Aborting...")
+                    sys.exit(0)
         else:
-            print("Aborting...")
-            sys.exit(0)
-    else:
-        print("Auth Error: %s" % response.text)
+            print("Auth Error: %s" % response.text)
+            return None
+    except Exception as e:
+        print("Error: %s" % e)
         return None
+    finally:
+        session.close()
 
 
-def get_all_files(auth_token: str, tree_url, repo_url):
+def get_all_files(auth_token: str, tree_url, repo_url, force: bool) -> None:
     session = requests.Session()
+    try:
+        headers = {
+            'Accept': 'application/vnd.github.v3+json',
+            'Authorization': f'Bearer {auth_token}',
+            'Cookie': '_octo=GH1.1.613847517.1655532567; logged_in=no'
+        }
 
-    headers = {
-        'Accept': 'application/vnd.github.v3+json',
-        'Authorization': f'Bearer {auth_token}',
-        'Cookie': '_octo=GH1.1.613847517.1655532567; logged_in=no'
-    }
+        response = session.request("GET", tree_url, headers=headers)
 
-    response = session.request("GET", tree_url, headers=headers)
-
-    if response.status_code == 200:
-        response_json = response.json()
-        for file in response_json['tree']:
-            if file['type'] == 'blob':
-                print(">> Downloading file: %s" % file['path'])
-                url = f"https://api.github.com/repos/{repo_url}/contents/" + file['path']
-                download_and_replace_file(session, url, file['path'], auth_token)
-    else:
-        print("Auth Error: %s" % response.text)
+        if response.status_code == 200:
+            response_json = response.json()
+            for file in response_json['tree']:
+                if file['type'] == 'blob':
+                    print(">> Downloading file: %s" % file['path'])
+                    url = f"https://api.github.com/repos/{repo_url}/contents/" + file['path']
+                    download_and_replace_file(session, url, file['path'], auth_token)
+        else:
+            print("Auth Error: %s" % response.text)
+            return None
+    except Exception as e:
+        print("Error: %s" % e)
         return None
+    finally:
+        session.close()
+
+
+def get_token_from_env() -> str or None:
+    """
+    Get the token from the environment variable
+    :return:
+    """
+    token = os.getenv('GITHUB_TOKEN')
+    if token is None:
+        print(">> [GITHUB_TOKEN] No token found in environment variable 'GITHUB_TOKEN'")
+        return None
+    return token
 
 
 def main():
@@ -166,6 +183,12 @@ def main():
     # Add argument called update that requires no arguments
     parser.add_argument('-u', help='Update files', action='store_true')
 
+    # Add argument called -f that forces without asking for confirmation
+    parser.add_argument('-f', help='Force update', action='store_true')
+
+    # Add argument for the auth token
+    parser.add_argument('-t', help='Auth token', required=False)
+
     args = parser.parse_args()
     project_id = args.p
     print("Project ID: %s" % project_id)
@@ -182,8 +205,13 @@ def main():
                     # Get the project name using regex
                     project_name = re.search(r'project:(.*)', content).group(1)
                     print(">> Project name: %s" % project_name)
-
-                    token = input("Enter your GitHub token: ")
+                    github_token = get_token_from_env()
+                    if not args.t and github_token is None:
+                        token = input("Enter your GitHub token: ")
+                    elif github_token is not None:
+                        token = github_token
+                    else:
+                        token = args.t
 
                     git_url_input = project_name.rstrip('/')
 
@@ -200,10 +228,10 @@ def main():
                             print(">> No files found in the current directory, downloading latest version...")
                             get_all_files(token,
                                           f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
-                                          git_url_input)
+                                          git_url_input, force=args.f)
                         else:
                             print(">> Found files in the current directory, updating latest version...")
-                            get_update_file(auth_token=token, repo_url=git_url_input)
+                            get_update_file(auth_token=token, repo_url=git_url_input, force=args.f)
 
                 else:
                     print(">> No project found in the UPDATE_FILE")
@@ -211,7 +239,12 @@ def main():
             print(">> No UPDATE_FILE found in root of folder")
     else:
         try:
-            token = input("Enter your GitHub token: ")
+            github_token = get_token_from_env()
+            git_token = ""
+            if github_token is None:
+                git_token = input("Enter your GitHub token: ")
+            elif github_token is not None:
+                git_token = github_token
 
             print(">> Executing mesh_sync version %s." % __version__)
             if check_if_dot_git_exists():
@@ -219,7 +252,7 @@ def main():
                 git_url = find_git_url()
                 if git_url is not None:
                     print(">> Found git url: %s" % git_url)
-                    get_update_file(auth_token=token, repo_url=git_url)
+                    get_update_file(auth_token=git_token, repo_url=git_url, force=args.f)
             else:
 
                 print(">> Could not find .git url")
@@ -242,11 +275,11 @@ def main():
                     is_empty = os.listdir(os.getcwd()) == []
                     if is_empty:
                         print(">> No files found in the current directory, downloading latest version...")
-                        get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
-                                      git_url_input)
+                        get_all_files(git_token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1",
+                                      git_url_input, force=args.f)
                     else:
                         print(">> Found files in the current directory, updating latest version...")
-                        get_update_file(auth_token=token, repo_url=git_url_input)
+                        get_update_file(auth_token=git_token, repo_url=git_url_input, force=args.f)
                 else:
                     print("Please enter a valid git url. Aborting...")
                     sys.exit(0)
